.. _ref_user_guide:


User guide
==========

This section explains key concepts for implementing the tools in Ansys Common Tools in your PyAnsys workflows. You can use these tools in your examples as well as integrate them into your own code.

.. important::
   Ansys Common Tools only supports the last two major versions of Python. Usage with older versions might not work.



.. grid:: 1 2 2 2

    .. grid-item-card:: Ansys path tool
        :padding: 2 2 2 2
        :link: ansys_tools_path
        :link-type: doc

        Learn how to use the Ansys path tool.

    .. grid-item-card:: Ansys example downloader
        :padding: 2 2 2 2
        :link: ansys_downloader
        :link-type: doc

        Learn how to use the example downloader.

    .. grid-item-card:: Ansys exceptions
        :padding: 2 2 2 2
        :link: ansys_exceptions
        :link-type: doc

        Learn how to use the common exceptions.

    .. grid-item-card:: Ansys versioning tool
        :padding: 2 2 2 2
        :link: versioning
        :link-type: doc

        Learn how to use the versioning tool.

    .. grid-item-card:: Ansys report tool
        :padding: 2 2 2 2
        :link: report
        :link-type: doc

        Learn how to use the report tool.

    .. grid-item-card:: Ansys local launcher tool
        :padding: 2 2 2 2
        :link: launcher/index
        :link-type: doc

        Learn how to use the local launcher tool.

    .. grid-item-card:: Securing gRPC connections
        :padding: 2 2 2 2
        :link: secure_grpc
        :link-type: doc

        Learn how to secure gRPC connections in PyAnsys.

.. toctree::
    :hidden:
    :maxdepth: 3

    ansys_tools_path
    ansys_downloader
    ansys_exceptions
    versioning
    report
    launcher/index
    secure_grpc
